/*
 * Copyright 2013 Vincent Oostindië
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License
 */

package nl.ulso.sprox.impl;

import nl.ulso.sprox.XmlProcessorException;

import javax.xml.stream.events.XMLEvent;

import static javax.xml.stream.XMLStreamConstants.END_ELEMENT;
import static javax.xml.stream.XMLStreamConstants.START_ELEMENT;

final class InsideNodeEventHandler implements EventHandler {
    private final EventHandler parentEventHandler;
    private final ControllerMethod controllerMethod;

    InsideNodeEventHandler(EventHandler parentEventHandler, ControllerMethod controllerMethod) {
        this.parentEventHandler = parentEventHandler;
        this.controllerMethod = controllerMethod;
    }

    @Override
    public boolean matches(XMLEvent event, ExecutionContext context) {
        switch (event.getEventType()) {
            case START_ELEMENT:
                return context.isNodeFlagged(event.asStartElement().getName());
            case END_ELEMENT:
                return controllerMethod.isMatchingEndElement(event.asEndElement());
            default:
                return false;
        }
    }

    @Override
    public EventHandler process(XMLEvent event, ExecutionContext context) throws XmlProcessorException {
        switch (event.getEventType()) {
            case START_ELEMENT:
                return new NodeBodyEventHandler(this, controllerMethod.getOwner(), event.asStartElement().getName());
            case END_ELEMENT:
                controllerMethod.processEndElement(context);
                return parentEventHandler;
            default:
                throw new IllegalStateException("Unsupported event type: " + event.getEventType());
        }
    }
}
